@@ -26,6 +26,11 @@ babyphone - A baby monitor application on the Nokia N900.
 #include <QTimer>
 
 
+/*!
+  The constructor initializes the audio device and negotiates the audio stream 
+  format. The audio sampling is started but immediately suspended. The 
+  application has to resume it to receive audio data.
+*/
 AudioMonitor::AudioMonitor(Settings *settings, QObject *parent)
     :QIODevice(parent), itsSettings(settings)
 {
@@ -33,6 +38,7 @@ AudioMonitor::AudioMonitor(Settings *settings, QObject *parent)
     open(QIODevice::WriteOnly);
 
     // determine suitable audio format
+    QAudioFormat itsAudioFormat;
 
     // this is what we want
     itsAudioFormat.setFrequency(8000);
@@ -65,11 +71,12 @@ AudioMonitor::AudioMonitor(Settings *settings, QObject *parent)
 
     // reset counter
     itsCounter = 0;
-
-    //connect(itsDevice, SIGNAL(notify()), SLOT(status()));
 }
 
 
+/*!
+  The destructor closes the audio device.
+*/
 AudioMonitor::~AudioMonitor()
 {
     // close IODevice
@@ -80,6 +87,9 @@ AudioMonitor::~AudioMonitor()
 }
 
 
+/*!
+  starts audio sampling and sets its state accordingly.
+*/
 void AudioMonitor::start()
 {
     // start capturing
@@ -88,6 +98,9 @@ void AudioMonitor::start()
 }
 
 
+/*!
+  stops audio sampling and sets its state accordingly.
+*/
 void AudioMonitor::stop()
 {
     // stop capturing
@@ -96,6 +109,10 @@ void AudioMonitor::stop()
 }
 
 
+/*!
+  readDate needs to be implemented from the abstract parent's class but has no
+  functionality since we have an unidirectional audio stream.
+*/
 qint64 AudioMonitor::readData(char *data, qint64 maxlen)
 {
     Q_UNUSED(data)
@@ -105,16 +122,31 @@ qint64 AudioMonitor::readData(char *data, qint64 maxlen)
 }
 
 
+/*!
+  writeData implements the central audio analysis functionality. It processes 
+  the audio queue in quantities of AUDIO_SAMPLE_SUBINTERVAL. For each such 
+  buffer it determines the maximum audio sample value and adds this to a 
+  cummulated energy variable. After processing the whole data buffer this energy
+  variable is rescaled and represents the amplitude value, which is signalled
+  to the outside then.
+  
+  writeData also compares this audio amplitude with the given threshold of the
+  application settings and handles the time based audio counter based on this.
+  If the volume is above the threshold the configurable increment is added to 
+  the counter, otherwise the counter is decremented. The counter is reported
+  together with the volume in the signal.
+*/
 qint64 AudioMonitor::writeData(const char *data, qint64 len)
 {
     quint32 curEnergy = 0;
     qint16 max = 0;
+    qint16 samples = len/2;   // change data type to keep efficient
 
     // sample format is S16LE, only!
     const qint16 *buffer = (qint16*)data;
 
     // derive energy
-    for (int i = 0; i < len/2; ++i) {
+    for (int i = 0; i < samples; ++i) {
         // store maximum
         if (*buffer > max)
             max = *buffer;
@@ -133,7 +165,7 @@ qint64 AudioMonitor::writeData(const char *data, qint64 len)
 
     // scale volume
     int volume = itsSettings->itsAudioAmplify *
-                 log(curEnergy*itsSettings->AUDIO_SAMPLE_SUBINTERVAL/len);
+                 log(curEnergy*itsSettings->AUDIO_SAMPLE_SUBINTERVAL/(float)samples);
     // inhibit negative values from logarithm
     if (volume < 0)
         volume = 0;
@@ -156,15 +188,8 @@ qint64 AudioMonitor::writeData(const char *data, qint64 len)
             itsCounter = 0;
     }
 
+	// signal the resulting values
     emit update(itsCounter, volume);
 
     return len;
 }
-
-
-void AudioMonitor::status()
-{
-    qWarning() << "bytesReady = " << itsDevice->bytesReady()
-               << " bytes, elapsedUSecs = " << itsDevice->elapsedUSecs()
-               << ", processedUSecs = " << itsDevice->processedUSecs();
-}
