@@ -20,6 +20,19 @@ babyphone - A baby monitor application on the Nokia N900.
 #include "settings.h"
 
 
+/*!
+  AudioMonitor handles the input capture of audio data and analysis the data
+  stream to extract the audio volume.
+  It uses QAudioInput to gather audio data and provides a QIODevice to handle
+  the audio stream. The audio properties (sampling rate, quantisation) are set
+  as demanded and the audio stream is opened unidirectional to receive data 
+  only.
+  
+  AudioMonitor performes the volume analysis, compares this with the audio
+  threshold defined in the application Settings and performs the time based
+  audio analysis using a counter variable (itsCounter). The threshold check of
+  the counter variable is performed outside of AudioMonitor.
+*/
 class AudioMonitor : public QIODevice
 {
     Q_OBJECT
@@ -41,14 +54,15 @@ private:
 
 
 signals:
+    //! reports a new audio sample with its value and the time based threshold	counter
     void update(int counter, int value);
 
+
 private slots:
-    void status();
 
 
 private:
-    QAudioFormat itsAudioFormat;
+    //! reference to global application settings
     Settings* const itsSettings;
 };
 
