@@ -15,19 +15,21 @@ babyphone - A baby monitor application on the Nokia N900.
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
+#include "contactchooser.h"
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
 
 #include <QDebug>
 #include <QMessageBox>
+#include <QInputDialog>
 #include <QtDBus>
 
 
 /*!
   The constructor sets up the main user interface and instantiates the 
-  AudioMonitor, the UserNotifier as well as the application Settings. It 
-  connects the signals from the AudioMonitor and UserNotifier to internal 
-  methods. As a last step it starts the audio monitoring.
+  AudioMonitor, ProfileSwitcher, as well as the application Settings.
+  It connects the signals from the AudioMonitor to internal methods.
+  As a last step it starts the audio monitoring.
 */
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
@@ -36,6 +38,9 @@ MainWindow::MainWindow(QWidget *parent) :
     // load settings
     itsSettings = new Settings(this);
 
+    // setup profile switcher
+    itsProfileSwitcher = new ProfileSwitcher(itsSettings, this);
+
     // setup audio monitor
     itsAudioMonitor = new AudioMonitor(itsSettings, this);
     connect(itsAudioMonitor, SIGNAL(update(int, int)), this, SLOT(refreshAudioData(int, int)));
@@ -56,7 +61,7 @@ MainWindow::MainWindow(QWidget *parent) :
         qWarning() << tr("Cannot connect to display status: ") << QDBusConnection::systemBus().lastError();
 
     // setup default UI values
-    ui->lineEdit_phone->setText(itsSettings->itsPhonenumber);
+    ui->label_contact->setText(itsSettings->itsContact.GetDisplayString());
 
     // setup graphs
     itsAudioLevelGraphics = new AudioLevelGraphicsScene(ui->graphicsViewLevel, itsSettings, this);
@@ -90,23 +95,6 @@ MainWindow::~MainWindow()
 }
 
 
-/*!
-  changeEvent reflects the Qt default implementation to switch the user 
-  interface language.
-*/
-void MainWindow::changeEvent(QEvent *e)
-{
-    QMainWindow::changeEvent(e);
-    switch (e->type()) {
-    case QEvent::LanguageChange:
-        ui->retranslateUi(this);
-        break;
-    default:
-        break;
-    }
-}
-
-
 /*!
   This user interface event trigger displays an about message box.
 */
@@ -125,10 +113,35 @@ void MainWindow::on_actionAbout_triggered()
   This user interface event trigger updates the value of the parent's phone 
   number.
 */
-void MainWindow::on_lineEdit_phone_textChanged()
+void MainWindow::on_pushButton_enterNumber_clicked()
 {
-    // update settings
-    itsSettings->itsPhonenumber = ui->lineEdit_phone->text();
+    bool resultOk;
+    QString text = QInputDialog::getText(this,
+                         tr("Babyphone Settings"),
+                         tr("Please enter the parent's phone number:"),
+                         QLineEdit::Normal,
+                         itsSettings->itsContact.itsPhoneNumber,
+                         &resultOk
+                    );
+    if (resultOk) {
+        // update settings
+        itsSettings->itsContact.SetNumber(text);
+        // update GUI
+        ui->label_contact->setText(itsSettings->itsContact.GetDisplayString());
+    }
+}
+
+
+/*!
+  on_pushButton_contacts_clicked is the event handler to start address book
+  contact selection.
+*/
+void MainWindow::on_pushButton_contacts_clicked()
+{
+    if (ContactChooser::contactChooser(&itsSettings->itsContact)) {
+        // update GUI
+        ui->label_contact->setText(itsSettings->itsContact.GetDisplayString());
+    }
 }
 
 
@@ -154,7 +167,7 @@ void MainWindow::on_pushButton_clicked()
         // switch ON
 
         // check whether we have a valid phone number
-        if (itsSettings->itsPhonenumber.size() > 0) {
+        if (itsSettings->itsContact.HasValidNumber()) {
             // activate it
             activateMonitor();
         }
@@ -180,8 +193,9 @@ void MainWindow::activateMonitor()
 {
     // update GUI
     ui->pushButton->setText(tr("Active - Waiting for activation delay"));
+    ui->pushButton_contacts->setEnabled(false);
+    ui->pushButton_enterNumber->setEnabled(false);
     ui->menuSettings->setEnabled(false);
-    ui->lineEdit_phone->setEnabled(false);
     if (itsSettings->itsDisableGraphs) {
         ui->graphicsViewCounter->setEnabled(false);
         ui->graphicsViewLevel->setEnabled(false);
@@ -189,8 +203,9 @@ void MainWindow::activateMonitor()
         itsAudioCounterGraphics->Clear();
     }
 
-    // setup phone call handler
-    itsUserNotifier = new UserNotifier(itsSettings);
+    // setup phone call handlers
+    itsCallMonitor = new CallMonitor(itsSettings, this);
+    itsUserNotifier = new UserNotifier(itsSettings, itsCallMonitor);
     connect(itsUserNotifier, SIGNAL(notifyFinished()), this, SLOT(notifyFinished()));
 
     // start activation timeout
@@ -214,11 +229,13 @@ void MainWindow::deactivateMonitor()
     // terminate phone call handler
     disconnect(itsUserNotifier, SIGNAL(notifyFinished()), this, SLOT(notifyFinished()));
     delete itsUserNotifier;
+    delete itsCallMonitor;
 
     // update GUI
     ui->pushButton->setText(tr("Inactive - Click to start"));
+    ui->pushButton_contacts->setEnabled(true);
+    ui->pushButton_enterNumber->setEnabled(true);
     ui->menuSettings->setEnabled(true);
-    ui->lineEdit_phone->setEnabled(true);
     if (itsSettings->itsDisableGraphs) {
         ui->graphicsViewCounter->setEnabled(true);
         ui->graphicsViewLevel->setEnabled(true);
@@ -341,15 +358,7 @@ void MainWindow::refreshAudioData(int counter, int value)
         if (itsUserNotifier->Notify() == false)
         {
             // the notify command yielded an error
-            QMessageBox *msgBox = new QMessageBox(QMessageBox::Critical, tr("Babyphone"),
-                  tr("Could not establish phone call. Please check the phone number settings."));
-            // the message box needs a timeout to keep the application active for retry
-            QTimer *msgBoxCloseTimer = new QTimer(msgBox);
-            msgBoxCloseTimer->setInterval(itsSettings->MSG_BOX_TIMEOUT);
-            msgBoxCloseTimer->setSingleShot(true);
-            connect(msgBoxCloseTimer, SIGNAL(timeout()), msgBox, SLOT(accept())); // or reject
-            msgBoxCloseTimer->start();
-            msgBox->exec();
+            showNotificationError();
 
             // restart audio capturing
             notifyFinished();
@@ -358,6 +367,40 @@ void MainWindow::refreshAudioData(int counter, int value)
 }
 
 
+/*!
+  showNotificationError displays the error message if the user notification
+  failed.
+*/
+void MainWindow::showNotificationError() const
+{
+    // determine proper error message
+    QString errorMsg;
+    if (itsSettings->itsUserNotifyScript.isEmpty())
+        errorMsg = tr("Could not establish phone call. Please check the phone number settings.");
+    else
+        errorMsg = QString(tr("Could not start user script %1.")
+                           .arg(itsSettings->itsUserNotifyScript));
+
+    // create message box
+    QMessageBox *msgBox = new QMessageBox(QMessageBox::Critical,
+                             tr("Babyphone"), errorMsg);
+
+    // the message box needs a timeout to keep the application active for retry
+    // no need to delete the timer, this is done together with the message box
+    QTimer *msgBoxCloseTimer = new QTimer(msgBox);
+    msgBoxCloseTimer->setInterval(itsSettings->MSG_BOX_TIMEOUT);
+    msgBoxCloseTimer->setSingleShot(true);
+    connect(msgBoxCloseTimer, SIGNAL(timeout()), msgBox, SLOT(accept())); // or reject
+    msgBoxCloseTimer->start();
+
+    // now we are ready to display the message box, the safety timer runs
+    msgBox->exec();
+
+    // delete message box, and with this also the timer
+    delete msgBox;
+}
+
+
 /*!
   displayDimmed updates the itsIsScreenOff flag based on DBus messages.
   Consider that itsIsScreenOff will be true even if the application is in
@@ -381,7 +424,7 @@ void MainWindow::displayDimmed(const QDBusMessage &msg)
 /*!
   showFirstRunInfo displays a popup at first run with some basic information.
 */
-void MainWindow::showFirstRunInfo()
+void MainWindow::showFirstRunInfo() const
 {
     // setup message
     QDBusMessage msg = QDBusMessage::createMethodCall(
