@@ -19,6 +19,7 @@ babyphone - A baby monitor application on the Nokia N900.
 #define SETTINGS_H
 
 #include <QSettings>
+#include "contact.h"
 
 
 /*!
@@ -43,9 +44,12 @@ private slots:
 
 
 public:
-	// variable settings
+    // variable settings
     //! the parent's phone number
-    QString itsPhonenumber;
+    Contact itsContact;
+
+    //! the user script to execute on babyphone audio triggering
+    QString itsUserNotifyScript;
 
     //! the volume based audio amplifcation factor
     int itsAudioAmplify;
@@ -86,6 +90,9 @@ public:
     //! decrement value for audio time counter in case of low audio amplitude
     const int VOLUME_COUNTER_DEC;
 
+    //! timeout to start external user notifier script
+    const int NOTIFY_SCRIPT_START_TIMEOUT;
+
     //! timeout after which an error message pop-up will be automatically closed
     const int MSG_BOX_TIMEOUT;
     //! timeout after a phone call until the application gets the UI focus again
