@@ -20,7 +20,9 @@ babyphone - A baby monitor application on the Nokia N900.
 
 #include <QObject>
 #include <QTimer>
+#include <QProcess>
 #include "settings.h"
+#include "callmonitor.h"
 
 
 // forward class declaration
@@ -28,8 +30,8 @@ class QDBusMessage;
 
 
 /*!
-  UserNotifier handles the whole notification interface to the parents phone, 
-  which includes the voice call setup and rejecting of incoming calls.
+  UserNotifier handles the notification interface to the parents phone,
+  which includes voice call setup and SMS notifications on missed calls.
   
   UserNotifier receives incoming notification requests and establishes a phone
   call then. This is done by the normal phone applicaton in Maemo using the DBus
@@ -37,25 +39,21 @@ class QDBusMessage;
   timeouts. As the call is ended or aborted, it emits a notifyFinished signal
   such that the calling class can continue its work (i.e. the audio monitoring).
   
-  This class is the only platform dependant component of the application. It 
-  uses the DBus interface with specific messages as needed by Maemo 5. Since
-  this DBus interface is only unofficially documented it may be subject to 
-  change in future releases, e.g. in MaeGo.
+  This class uses the DBus interface with specific messages as needed by Maemo 5.
+  Since this DBus interface is only unofficially documented it may be subject to
+  change in future releases.
 */
 class UserNotifier : public QObject
 {
     Q_OBJECT
 public:
-    explicit UserNotifier(Settings *settings, QObject *parent = 0);
-    ~UserNotifier();
-
+    explicit UserNotifier(Settings *settings, CallMonitor *callMonitor, QObject *parent = 0);
     bool Notify();
 
 private:
-    bool dropIncomingCall() const;
-    bool takeIncomingCall();
-    bool notifySMS(const QString droppedPhoneNumber) const;
-
+    bool NotifyPhone();
+    bool NotifyScript();
+    bool dropCall() const;
 
 signals:
     /*!
@@ -68,23 +66,27 @@ signals:
     */
     void notifyFinished();
 
+public slots:
+    void callStatusChanged(bool newStatus);
+    void notifySMS(const QString droppedPhoneNumber);
+    void userNotfierFinished(int exitCode);
+
 
 private slots:
     void callSetupTimer();
-    void callEstablished(const QDBusMessage&);
-    void receiveCall(const QDBusMessage&);
-    void callStatusUpdate(const QDBusMessage&);
 
 
 private:
     //! reference to global application settings
     Settings* const itsSettings;
-    //! timeout to abort outgoing voice calls
+    //! reference to phone call monitor
+    CallMonitor* const itsCallMonitor;
+    //! timeout to abort unanswered outgoing voice calls
     QTimer *itsCallTimer;
-    //! initially active phone profile
-    QString itsInitialProfile;
-    //! indicates whether a call is active
-    bool itsCallPending;
+    //! indicates whether a notification call is active
+    bool itsNotificationPending;
+    //! notifier script, used depending on settings
+    QProcess *notifyScript;
 };
 
 #endif // USERNOTIFIER_H
